@@ -5,10 +5,10 @@ package Text::FileTree;
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-our $VERSION = 0.22;
-
 use warnings FATAL => 'all';
 use strict;
+our $VERSION = 0.23;
+
 use Carp;
 use File::Slurp;
 use File::Spec;
@@ -64,7 +64,7 @@ sub new {
 	}, $class;
 
 	if($self->{platform}) {
-		require "File/Spec/$self->{platform}.pm";
+		load "File::Spec::$self->{platform}";
 		$self->{fs} = "File::Spec::$self->{platform}";
 	}
 
@@ -118,7 +118,7 @@ sub from_file {
 Load the file list from a filehandle (or a filename). Examples:
 
  open(my $pipe, '-|', 'find', '/');
- Text::FileTree::from_fh($pipe);
+ Text::FileTree->new->from_fh($pipe);
 
 =cut
 
@@ -135,14 +135,23 @@ development version is available on github:
 
 =over
 
-=item * L<http://metacpan.org/Text::FileTree>
+=item * L<https://metacpan.org/pod/Text::FileTree>
 
-=item * L<http://github.com/olof/Text-FileTree>
+=item * L<https://github.com/olof/Text-FileTree>
 
 =back
 
-Bugs can be reported on either rt.cpan.org, as an issue on github
-or as an e-mail to me. The primary issue tracker is github.
+We use Github for issue tracking and pull requests.
+
+=over
+
+=item * L<https://github.com/olof/Text-FileTree/issues>
+
+=back
+
+If you don't have an account on Github (or for other reason don't
+want to use Github), we are ok with bugs filed on rt.cpan.org as
+well.
 
 =head1 KNOWN BUGS AND LIMITATIONS
 
